@@ -1,7 +1,7 @@
-from .gaussian import DiagGaussian
+from .gaussian import DiagGaussian, DiagGaussianEnsemble
 from .categorical import Categorical
 from .squashed_gaussian import SquashedGaussian
-from .deterministic import Deterministic
+from .deterministic import Deterministic, DeterministicMB
 
 
 def get_dist(name):
@@ -14,5 +14,7 @@ def get_dist(name):
         return SquashedGaussian
     elif name == "Deterministic":
         return Deterministic
+    elif name == "DeterministicMB":
+        return DeterministicMB
     else:
         raise ValueError("Specified model not found!")
\ No newline at end of file
