@@ -1,5 +1,6 @@
 from .gaussian import Normal
 from .ou import OUNoise
+from .nonoise import NoNoise
 
 def get_noise(name):
     """Returns noise model class from name."""
@@ -7,5 +8,7 @@ def get_noise(name):
         return Normal
     elif name == "OU":
         return OUNoise
+    elif name == "NoNoise":
+        return  NoNoise
     else:
         raise ValueError("Specified Noise not found!")
\ No newline at end of file
