@@ -1,3 +1,6 @@
+import logging
+logger = logging.getLogger(__name__)
+
 import pytorchrl as prl
 from pytorchrl.scheme.collection.c_worker_set import CWorkerSet
 from pytorchrl.scheme.gradients.g_worker_set import GWorkerSet
@@ -126,6 +129,8 @@ class Scheme:
             decentralized_update_execution=decentralized_update_execution,
         )
 
+        logger.warning("Created training scheme.")
+
     def update_worker(self):
         """Return local worker"""
         return self._update_worker
